@@ -1,7 +1,7 @@
 #
 # This file is part of CatalystX-ExtJS-REST
 #
-# This software is Copyright (c) 2011 by Moritz Onken.
+# This software is Copyright (c) 2014 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -17,8 +17,8 @@ use warnings;
 
 sub extjs_rest_user {
     my ($self, $c) = @_;
-    return $self unless(my $ending = $c->req->params->{ending});
-    return $self->search({ id => { LIKE => '%'.$ending }  });
+    return $self unless(my $gt = $c->req->params->{gt});
+    return $self->search({ id => { ">" => $gt } });
 }
 
 sub hri {
